import{S as p,i as $,s as h,q as c,u as m,v as i,w as f,x as d,K as C,R as b,m as k,c as S,L as w,M as q,N as v,O as j,P as E,e as K,E as L}from"./index.35088c78.js";import{C as M}from"./CarouselItem.svelte_svelte_type_style_lang.1ecd32bd.js";import{S as N}from"./StatusTracker.1a97f223.js";function O(n){let t,o,s;const r=[n[1]];let l={};for(let e=0;e<r.length;e+=1)l=C(l,r[e]);t=new N({props:l});const _=n[2].default,a=b(_,n,n[4],null);return{c(){c(t.$$.fragment),o=k(),a&&a.c()},m(e,u){m(t,e,u),S(e,o,u),a&&a.m(e,u),s=!0},p(e,u){const g=u&2?w(r,[q(e[1])]):{};t.$set(g),a&&a.p&&(!s||u&16)&&v(a,_,e,e[4],s?E(_,e[4],u,null):j(e[4]),null)},i(e){s||(i(t.$$.fragment,e),i(a,e),s=!0)},o(e){f(t.$$.fragment,e),f(a,e),s=!1},d(e){d(t,e),e&&K(o),a&&a.d(e)}}}function P(n){let t,o;return t=new M({props:{elem_id:n[0],$$slots:{default:[O]},$$scope:{ctx:n}}}),t.$on("change",n[3]),{c(){c(t.$$.fragment)},m(s,r){m(t,s,r),o=!0},p(s,[r]){const l={};r&1&&(l.elem_id=s[0]),r&18&&(l.$$scope={dirty:r,ctx:s}),t.$set(l)},i(s){o||(i(t.$$.fragment,s),o=!0)},o(s){f(t.$$.fragment,s),o=!1},d(s){d(t,s)}}}function R(n,t,o){let{$$slots:s={},$$scope:r}=t,{elem_id:l=""}=t,{loading_status:_}=t;function a(e){L.call(this,n,e)}return n.$$set=e=>{"elem_id"in e&&o(0,l=e.elem_id),"loading_status"in e&&o(1,_=e.loading_status),"$$scope"in e&&o(4,r=e.$$scope)},[l,_,s,a,r]}class T extends p{constructor(t){super(),$(this,t,R,P,h,{elem_id:0,loading_status:1})}}var D=T;const F=["static"];export{D as Component,F as modes};
