import{S as w,i as k,s as _,f as y,q as I,b as l,c as b,d as g,u as z,l as j,n as u,v as d,w as h,e as v,x as $,E as L,a as m,Y as c,m as B,t as p,y as E,z as q,A as S}from"./index.35088c78.js";function A(i){let e,r,t,s,n,o;return t=new i[0]({}),{c(){e=y("button"),r=y("div"),I(t.$$.fragment),l(r,"class","m-t-1 w-[60%] h-[60%] opacity-80 dark:text-white"),l(e,"class","text-gray-500 bg-white/90 h-5 w-5 flex items-center justify-center rounded shadow-sm hover:shadow-xl hover:ring-1 ring-inset ring-gray-200 z-10 dark:bg-gray-900 dark:ring-gray-600")},m(a,x){b(a,e,x),g(e,r),z(t,r,null),s=!0,n||(o=j(e,"click",i[1]),n=!0)},p:u,i(a){s||(d(t.$$.fragment,a),s=!0)},o(a){h(t.$$.fragment,a),s=!1},d(a){a&&v(e),$(t),n=!1,o()}}}function D(i,e,r){let{Icon:t}=e;function s(n){L.call(this,i,n)}return i.$$set=n=>{"Icon"in n&&r(0,t=n.Icon)},[t,s]}class M extends w{constructor(e){super(),k(this,e,D,A,_,{Icon:0})}}function U(i){let e,r,t,s;return{c(){e=m("svg"),r=m("g"),t=m("path"),s=m("path"),l(t,"d","M18,6L6.087,17.913"),c(t,"fill","none"),c(t,"fill-rule","nonzero"),c(t,"stroke-width","2px"),l(r,"transform","matrix(1.14096,-0.140958,-0.140958,1.14096,-0.0559523,0.0559523)"),l(s,"d","M4.364,4.364L19.636,19.636"),c(s,"fill","none"),c(s,"fill-rule","nonzero"),c(s,"stroke-width","2px"),l(e,"width","100%"),l(e,"height","100%"),l(e,"viewBox","0 0 24 24"),l(e,"version","1.1"),l(e,"xmlns","http://www.w3.org/2000/svg"),l(e,"xmlns:xlink","http://www.w3.org/1999/xlink"),l(e,"xml:space","preserve"),l(e,"stroke","currentColor"),c(e,"fill-rule","evenodd"),c(e,"clip-rule","evenodd"),c(e,"stroke-linecap","round"),c(e,"stroke-linejoin","round")},m(n,o){b(n,e,o),g(e,r),g(r,t),g(e,s)},p:u,i:u,o:u,d(n){n&&v(e)}}}class Y extends w{constructor(e){super(),k(this,e,null,U,_,{})}}function F(i){let e,r;return{c(){e=m("svg"),r=m("path"),l(r,"d","M17 3a2.828 2.828 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5L17 3z"),l(e,"xmlns","http://www.w3.org/2000/svg"),l(e,"width","100%"),l(e,"height","100%"),l(e,"viewBox","0 0 24 24"),l(e,"fill","none"),l(e,"stroke","currentColor"),l(e,"stroke-width","1.5"),l(e,"stroke-linecap","round"),l(e,"stroke-linejoin","round"),l(e,"class","feather feather-edit-2")},m(t,s){b(t,e,s),g(e,r)},p:u,i:u,o:u,d(t){t&&v(e)}}}class G extends w{constructor(e){super(),k(this,e,null,F,_,{})}}function C(i){let e,r;return e=new M({props:{Icon:G}}),e.$on("click",i[4]),{c(){I(e.$$.fragment)},m(t,s){z(e,t,s),r=!0},p:u,i(t){r||(d(e.$$.fragment,t),r=!0)},o(t){h(e.$$.fragment,t),r=!1},d(t){$(e,t)}}}function H(i){let e,r,t,s,n=i[0]&&C(i);return t=new M({props:{Icon:Y}}),t.$on("click",i[5]),{c(){e=y("div"),n&&n.c(),r=B(),I(t.$$.fragment),l(e,"class","modify-upload z-10 top-2 right-2 justify-end flex gap-1"),p(e,"absolute",i[1]),p(e,"m-1",!i[1])},m(o,a){b(o,e,a),n&&n.m(e,null),g(e,r),z(t,e,null),s=!0},p(o,[a]){o[0]?n?(n.p(o,a),a&1&&d(n,1)):(n=C(o),n.c(),d(n,1),n.m(e,r)):n&&(E(),h(n,1,1,()=>{n=null}),q()),a&2&&p(e,"absolute",o[1]),a&2&&p(e,"m-1",!o[1])},i(o){s||(d(n),d(t.$$.fragment,o),s=!0)},o(o){h(n),h(t.$$.fragment,o),s=!1},d(o){o&&v(e),n&&n.d(),$(t)}}}function J(i,e,r){let{editable:t=!1}=e,{absolute:s=!0}=e,{style:n=""}=e;const o=S(),a=()=>o("edit"),x=()=>o("clear");return i.$$set=f=>{"editable"in f&&r(0,t=f.editable),"absolute"in f&&r(1,s=f.absolute),"style"in f&&r(3,n=f.style)},[t,s,o,n,a,x]}class N extends w{constructor(e){super(),k(this,e,J,H,_,{editable:0,absolute:1,style:3})}}export{Y as C,M as I,N as M};
