import{S as _,i as m,s as g,R as d,f as c,b as r,t as o,c as v,N as p,O as b,P as w,v as C,w as h,e as S}from"./index.35088c78.js";function q(n){let e,t;const f=n[4].default,l=d(f,n,n[3],null);return{c(){e=c("div"),l&&l.c(),r(e,"id",n[0]),r(e,"class","flex flex-col gr-gap gr-form-gap relative col overflow-auto"),o(e,"bg-gray-50",n[1]==="panel"),o(e,"p-2",n[1]==="panel"),o(e,"rounded-lg",n[1]==="panel"),o(e,"flex-1",n[2]==="row"||!n[2])},m(a,s){v(a,e,s),l&&l.m(e,null),t=!0},p(a,[s]){l&&l.p&&(!t||s&8)&&p(l,f,a,a[3],t?w(f,a[3],s,null):b(a[3]),null),(!t||s&1)&&r(e,"id",a[0]),s&2&&o(e,"bg-gray-50",a[1]==="panel"),s&2&&o(e,"p-2",a[1]==="panel"),s&2&&o(e,"rounded-lg",a[1]==="panel"),s&4&&o(e,"flex-1",a[2]==="row"||!a[2])},i(a){t||(C(l,a),t=!0)},o(a){h(l,a),t=!1},d(a){a&&S(e),l&&l.d(a)}}}function N(n,e,t){let{$$slots:f={},$$scope:l}=e,{elem_id:a=""}=e,{variant:s="default"}=e,{parent:u=null}=e;return n.$$set=i=>{"elem_id"in i&&t(0,a=i.elem_id),"variant"in i&&t(1,s=i.variant),"parent"in i&&t(2,u=i.parent),"$$scope"in i&&t(3,l=i.$$scope)},[a,s,u,l,f]}class O extends _{constructor(e){super(),m(this,e,N,q,g,{elem_id:0,variant:1,parent:2})}}var R=O;const j=["static"];export{R as Component,j as modes};
