import{S as f,i,s as u,R as _,f as c,b as m,t as r,c as p,N as d,O as g,P as w,v,w as R,e as b}from"./index.35088c78.js";function h(n){let s,a;const o=n[2].default,t=_(o,n,n[1],null);return{c(){s=c("div"),t&&t.c(),m(s,"class","flex flex-col md:flex-row gr-gap gr-form-gap row w-full flex-none"),r(s,"flex-1",n[0]==="row")},m(e,l){p(e,s,l),t&&t.m(s,null),a=!0},p(e,[l]){t&&t.p&&(!a||l&2)&&d(t,o,e,e[1],a?w(o,e[1],l,null):g(e[1]),null),l&1&&r(s,"flex-1",e[0]==="row")},i(e){a||(v(t,e),a=!0)},o(e){R(t,e),a=!1},d(e){e&&b(s),t&&t.d(e)}}}function C(n,s,a){let{$$slots:o={},$$scope:t}=s,{parent:e=null}=s;return n.$$set=l=>{"parent"in l&&a(0,e=l.parent),"$$scope"in l&&a(1,t=l.$$scope)},[e,t,o]}class S extends f{constructor(s){super(),i(this,s,C,h,u,{parent:0})}}var x=S;const N=["static"];export{x as Component,N as modes};
