import{S as m,i as b,s as d,R as z,f as B,b as _,c as g,l as C,N as q,O as w,P as S,v,w as h,e as y,E as k,q as j,u as E,x as J,J as N,X as O,h as P,j as R}from"./index.35088c78.js";import{s as c}from"./styles.bc3c1b88.js";function X(n){let e,l,t,a,o;const r=n[5].default,u=z(r,n,n[4],null);return{c(){e=B("button"),u&&u.c(),_(e,"class",l=`gr-button gr-button-${n[3]} gr-button-${n[2]} self-start flex-1`+c(n[0])),_(e,"id",n[1])},m(s,i){g(s,e,i),u&&u.m(e,null),t=!0,a||(o=C(e,"click",n[6]),a=!0)},p(s,[i]){u&&u.p&&(!t||i&16)&&q(u,r,s,s[4],t?S(r,s[4],i,null):w(s[4]),null),(!t||i&13&&l!==(l=`gr-button gr-button-${s[3]} gr-button-${s[2]} self-start flex-1`+c(s[0])))&&_(e,"class",l),(!t||i&2)&&_(e,"id",s[1])},i(s){t||(v(u,s),t=!0)},o(s){h(u,s),t=!1},d(s){s&&y(e),u&&u.d(s),a=!1,o()}}}function A(n,e,l){let{$$slots:t={},$$scope:a}=e,{style:o={}}=e,{elem_id:r=""}=e,{variant:u="secondary"}=e,{size:s="lg"}=e;function i(f){k.call(this,n,f)}return n.$$set=f=>{"style"in f&&l(0,o=f.style),"elem_id"in f&&l(1,r=f.elem_id),"variant"in f&&l(2,u=f.variant),"size"in f&&l(3,s=f.size),"$$scope"in f&&l(4,a=f.$$scope)},[o,r,u,s,a,t,i]}class D extends m{constructor(e){super(),b(this,e,A,X,d,{style:0,elem_id:1,variant:2,size:3})}}function F(n){let e=n[4](n[2])+"",l;return{c(){l=P(e)},m(t,a){g(t,l,a)},p(t,a){a&20&&e!==(e=t[4](t[2])+"")&&R(l,e)},d(t){t&&y(l)}}}function G(n){let e,l;return e=new D({props:{variant:n[3],elem_id:n[1],style:n[0],$$slots:{default:[F]},$$scope:{ctx:n}}}),e.$on("click",n[5]),{c(){j(e.$$.fragment)},m(t,a){E(e,t,a),l=!0},p(t,[a]){const o={};a&8&&(o.variant=t[3]),a&2&&(o.elem_id=t[1]),a&1&&(o.style=t[0]),a&84&&(o.$$scope={dirty:a,ctx:t}),e.$set(o)},i(t){l||(v(e.$$.fragment,t),l=!0)},o(t){h(e.$$.fragment,t),l=!1},d(t){J(e,t)}}}function H(n,e,l){let t;N(n,O,i=>l(4,t=i));let{style:a={}}=e,{elem_id:o=""}=e,{value:r}=e,{variant:u="primary"}=e;function s(i){k.call(this,n,i)}return n.$$set=i=>{"style"in i&&l(0,a=i.style),"elem_id"in i&&l(1,o=i.elem_id),"value"in i&&l(2,r=i.value),"variant"in i&&l(3,u=i.variant)},[a,o,r,u,t,s]}class I extends m{constructor(e){super(),b(this,e,H,G,d,{style:0,elem_id:1,value:2,variant:3})}}var M=I;const Q=["static"];export{M as Component,Q as modes};
