import{S as q,i as E,s as C,f as L,b as d,t as f,c as B,N as P,O as Q,P as R,v as N,w as k,e as K,k as T,Q as Y,R as j,T as z}from"./index.35088c78.js";import{s as h}from"./styles.bc3c1b88.js";function g(t){let e,o,r;const i=t[13].default,l=j(i,t,t[12],null);return{c(){e=L(t[9]),l&&l.c(),d(e,"data-testid",t[6]),d(e,"id",t[1]),d(e,"class",o="gr-box overflow-hidden"+t[8][t[2]]+" "+t[8][t[3]]+" "+t[7]+h(t[0],"container")),f(e,"gr-panel",t[4]),f(e,"form",t[5]),f(e,"flex-1",t[10]==="row"||null)},m(n,a){B(n,e,a),l&&l.m(e,null),r=!0},p(n,a){l&&l.p&&(!r||a&4096)&&P(l,i,n,n[12],r?R(i,n[12],a,null):Q(n[12]),null),(!r||a&64)&&d(e,"data-testid",n[6]),(!r||a&2)&&d(e,"id",n[1]),(!r||a&141&&o!==(o="gr-box overflow-hidden"+n[8][n[2]]+" "+n[8][n[3]]+" "+n[7]+h(n[0],"container")))&&d(e,"class",o),a&157&&f(e,"gr-panel",n[4]),a&173&&f(e,"form",n[5]),a&1165&&f(e,"flex-1",n[10]==="row"||null)},i(n){r||(N(l,n),r=!0)},o(n){k(l,n),r=!1},d(n){n&&K(e),l&&l.d(n)}}}function A(t){let e=t[9],o,r,i=t[9]&&g(t);return{c(){i&&i.c(),o=T()},m(l,n){i&&i.m(l,n),B(l,o,n),r=!0},p(l,[n]){l[9]?e?C(e,l[9])?(i.d(1),i=g(l),i.c(),i.m(o.parentNode,o)):i.p(l,n):(i=g(l),i.c(),i.m(o.parentNode,o)):e&&(i.d(1),i=null),e=l[9]},i(l){r||(N(i),r=!0)},o(l){k(i),r=!1},d(l){l&&K(o),i&&i.d(l)}}}function D(t,e,o){let r,{$$slots:i={},$$scope:l}=e,{style:n={}}=e,{elem_id:a=""}=e,{variant:b="solid"}=e,{color:c="grey"}=e,{padding:y=!0}=e,{form_position:u=void 0}=e,{type:_="normal"}=e,{test_id:v=void 0}=e;const O={dashed:"border-dashed border-[3px]",solid:"border-solid border",grey:"border-gray-200",green:"border-green-400",none:"!border-0"},m={column:{first:"!rounded-b-none",last:"!rounded-t-none",mid:"!rounded-none",single:""},row:{first:"!rounded-r-none",last:"!rounded-l-none",mid:"!rounded-none",single:""}};let S=_==="fieldset"?"fieldset":"div";const w=Y(z);return t.$$set=s=>{"style"in s&&o(0,n=s.style),"elem_id"in s&&o(1,a=s.elem_id),"variant"in s&&o(2,b=s.variant),"color"in s&&o(3,c=s.color),"padding"in s&&o(4,y=s.padding),"form_position"in s&&o(5,u=s.form_position),"type"in s&&o(11,_=s.type),"test_id"in s&&o(6,v=s.test_id),"$$scope"in s&&o(12,l=s.$$scope)},t.$$.update=()=>{t.$$.dirty&32&&o(7,r=u?m==null?void 0:m[w||"column"][u]:"")},[n,a,b,c,y,u,v,r,O,S,w,_,l,i]}class H extends q{constructor(e){super(),E(this,e,D,A,C,{style:0,elem_id:1,variant:2,color:3,padding:4,form_position:5,type:11,test_id:6})}}export{H as B};
