.image_editor_buttons{width:800px;display:flex;justify-content:flex-end;gap:.25rem}.image_editor_buttons button{border-top-left-radius:.25rem;border-top-right-radius:.25rem;--tw-bg-opacity:1;background-color:rgb(0 0 0 / var(--tw-bg-opacity));padding:.25rem .5rem;font-size:1.25rem;line-height:1.75rem;font-weight:600;--tw-text-opacity:1;color:rgb(255 255 255 / var(--tw-text-opacity))}.tui-image-editor-header-buttons{display:none}.tui-colorpicker-palette-button{width:12px;height:12px}
