import{S as m,i as o,s as d,f as h,b as c,c as v,n as r,e as g,A as _,q as b,u as H,v as L,w as M,x as T,E as q}from"./index.35088c78.js";function w(a){let e;return{c(){e=h("div"),c(e,"class","output-html"),c(e,"id",a[0])},m(n,t){v(n,e,t),e.innerHTML=a[1]},p(n,[t]){t&2&&(e.innerHTML=n[1]),t&1&&c(e,"id",n[0])},i:r,o:r,d(n){n&&g(e)}}}function C(a,e,n){let{elem_id:t=""}=e,{value:i}=e;const l=_();return a.$$set=u=>{"elem_id"in u&&n(0,t=u.elem_id),"value"in u&&n(1,i=u.value)},a.$$.update=()=>{a.$$.dirty&2&&l("change")},[t,i]}class E extends m{constructor(e){super(),o(this,e,C,w,d,{elem_id:0,value:1})}}function S(a){let e,n;return e=new E({props:{value:a[1],elem_id:a[0]}}),e.$on("change",a[3]),{c(){b(e.$$.fragment)},m(t,i){H(e,t,i),n=!0},p(t,[i]){const l={};i&2&&(l.value=t[1]),i&1&&(l.elem_id=t[0]),e.$set(l)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){T(e,t)}}}function y(a,e,n){let{label:t}=e,{elem_id:i=""}=e,{value:l=""}=e;const u=_();function f(s){q.call(this,a,s)}return a.$$set=s=>{"label"in s&&n(2,t=s.label),"elem_id"in s&&n(0,i=s.elem_id),"value"in s&&n(1,l=s.value)},a.$$.update=()=>{a.$$.dirty&4&&u("change")},[i,l,t,f]}class A extends m{constructor(e){super(),o(this,e,y,S,d,{label:2,elem_id:0,value:1})}}var j=A;const k=["static"];export{j as Component,k as modes};
