import{S as $,i as g,s as b,f as h,h as O,b as v,c as C,d as k,j as R,e as w,R as I,m as j,t as _,N as S,O as q,P as D,v as f,w as c,Q as y,J as z,D as A,q as E,u as J,x as L}from"./index.35088c78.js";import{a as N}from"./CarouselItem.svelte_svelte_type_style_lang.1ecd32bd.js";function p(n){let t,l;return{c(){t=h("div"),l=O(n[0]),v(t,"class","absolute left-0 top-0 py-1 px-2 rounded-br-lg shadow-sm text-xs text-gray-500 flex items-center pointer-events-none bg-white z-20 dark:bg-gray-800 svelte-1n4s1e3")},m(s,e){C(s,t,e),k(t,l)},p(s,e){e&1&&R(l,s[0])},d(s){s&&w(t)}}}function P(n){let t,l,s,e=n[0]&&p(n);const a=n[5].default,r=I(a,n,n[4],null);return{c(){t=h("div"),e&&e.c(),l=j(),r&&r.c(),v(t,"class","carousel-item hidden component min-h-[200px] border rounded-lg overflow-hidden relative svelte-1n4s1e3"),_(t,"!block",n[1]===n[3])},m(o,i){C(o,t,i),e&&e.m(t,null),k(t,l),r&&r.m(t,null),s=!0},p(o,[i]){o[0]?e?e.p(o,i):(e=p(o),e.c(),e.m(t,l)):e&&(e.d(1),e=null),r&&r.p&&(!s||i&16)&&S(r,a,o,o[4],s?D(a,o[4],i,null):q(o[4]),null),i&10&&_(t,"!block",o[1]===o[3])},i(o){s||(f(r,o),s=!0)},o(o){c(r,o),s=!1},d(o){o&&w(t),e&&e.d(),r&&r.d(o)}}}function Q(n,t,l){let s,{$$slots:e={},$$scope:a}=t,{label:r=void 0}=t;const{register:o,unregister:i,current:m}=y(N);z(n,m,u=>l(1,s=u));let d=o();return A(()=>i(d)),n.$$set=u=>{"label"in u&&l(0,r=u.label),"$$scope"in u&&l(4,a=u.$$scope)},[r,s,m,d,a,e]}class U extends ${constructor(t){super(),g(this,t,Q,P,b,{label:0})}}function B(n){let t;const l=n[0].default,s=I(l,n,n[1],null);return{c(){s&&s.c()},m(e,a){s&&s.m(e,a),t=!0},p(e,a){s&&s.p&&(!t||a&2)&&S(s,l,e,e[1],t?D(l,e[1],a,null):q(e[1]),null)},i(e){t||(f(s,e),t=!0)},o(e){c(s,e),t=!1},d(e){s&&s.d(e)}}}function F(n){let t,l;return t=new U({props:{$$slots:{default:[B]},$$scope:{ctx:n}}}),{c(){E(t.$$.fragment)},m(s,e){J(t,s,e),l=!0},p(s,[e]){const a={};e&2&&(a.$$scope={dirty:e,ctx:s}),t.$set(a)},i(s){l||(f(t.$$.fragment,s),l=!0)},o(s){c(t.$$.fragment,s),l=!1},d(s){L(t,s)}}}function G(n,t,l){let{$$slots:s={},$$scope:e}=t;return n.$$set=a=>{"$$scope"in a&&l(1,e=a.$$scope)},[s,e]}class H extends ${constructor(t){super(),g(this,t,G,F,b,{})}}var T=H;const V=["static"];export{T as Component,V as modes};
