const t=(o,d="")=>{let e=[],r={};if(d==="")r=o;else for(const a in o)if(a.startsWith(d+"_")){const l=a.substring(a.indexOf("_")+1);r[l]=o[a]}switch(r.rounded){case!0:e.push("!rounded-lg");break;case!1:e.push("!rounded-none");break}switch(r.text_color){case"red":e.push("!text-red-500","dark:text-red-100");break;case"yellow":e.push("!text-yellow-500","dark:text-yellow-100");break;case"green":e.push("!text-green-500","dark:text-green-100");break;case"blue":e.push("!text-blue-500","dark:text-blue-100");break;case"purple":e.push("!text-purple-500","dark:text-purple-100");break;case"black":e.push("!text-gray-700","dark:text-gray-50");break}switch(r.bg_color){case"red":e.push("!bg-red-100 !from-red-100 !to-red-200 !border-red-300","dark:!bg-red-700 dark:!from-red-700 dark:!to-red-800 dark:!border-red-900");break;case"yellow":e.push("!bg-yellow-100 !from-yellow-100 !to-yellow-200 !border-yellow-300","dark:!bg-yellow-700 dark:!from-yellow-700 dark:!to-yellow-800 dark:!border-yellow-900");break;case"green":e.push("!bg-green-100 !from-green-100 !to-green-200 !border-green-300","dark:!bg-green-700 dark:!from-green-700 dark:!to-green-800 dark:!border-green-900");break;case"blue":e.push("!bg-blue-100 !from-blue-100 !to-blue-200 !border-blue-300","dark:!bg-blue-700 dark:!from-blue-700 dark:!to-blue-800 dark:!border-blue-900");break;case"purple":e.push("!bg-purple-100 !from-purple-100 !to-purple-200 !border-purple-300","dark:!bg-purple-700 dark:!from-purple-700 dark:!to-purple-800 dark:!border-purple-900");break;case"black":e.push("!bg-gray-100 !from-gray-100 !to-gray-200 !border-gray-300","dark:!bg-gray-700 dark:!from-gray-700 dark:!to-gray-800 dark:!border-gray-900");break}return" "+e.join(" ")};export{t as s};
